---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: aleneum

---

You have an idea for a feature that would make `transitions` more helpful or easier to use? Great! We are looking forward to your suggestion.

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Additional context**
Add any other context or screenshots about the feature request here.
